App-specific configuration extensions.
This module provides hotkey support on top of the core Config.
Traits
- Config
Ext - Extension trait for Config to handle hotkeys.
Functions
- default_
hotkey - Default hotkey: Meta+Shift+Semicolon
App-specific configuration extensions.
This module provides hotkey support on top of the core Config.